/* DeadLine.java
   Copyright 2012 Tommy Skodje (http://www.antares.no)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
package no.antares.clutil.hitman;


/** A deadline may expire or be extended
 * @author tommy skodje
*/
abstract class DeadLine {
	// deadLine is mutable and all access should be synchronized
	private static final long FAR_FUTURE	= Long.MAX_VALUE;
	private long deadLine	= FAR_FUTURE;
	private int[] deadLineMonitor	= {};

	/** Implementor decides what to do when expired */
	abstract void expired();

	/** Builder of DeadLine - construct and start with checkAtFixedRate().startIn() */
	DeadLineChecker checkAtFixedRate( long periodInMillis ) {
		return new DeadLineChecker( this, periodInMillis );
	}

	/** Extend timeout */
	protected void extend( Message message ) {
		synchronized ( deadLineMonitor ) {
			// wide block - because we want to spare a client that talks to us
			deadLine	= message.deadLine();
		}
	}

	protected void check() {
		if ( System.currentTimeMillis() <= deadLine )
        	return;
    	synchronized ( deadLineMonitor ) {
            if ( System.currentTimeMillis() <= deadLine )
            	return;
        	deadLine	= FAR_FUTURE;
    	}
       	expired();
	}

}
